==> vipps_recurring_payments-8.x-2.2-beta2.tar.gz: vipps_recurring_payments/src/RequestStorage/DraftAgreementData.php <==
<?php

declare(strict_types=1);

namespace Drupal\vipps_recurring_payments\RequestStorage;

use Drupal\vipps_recurring_payments\Entity\ProductSubscriptionInterface;

/**
 * Class Draft Agreement Data.
 *
 * @package Drupal\vipps_recurring_payments\RequestStorage
 */
class DraftAgreementData implements RequestStorageInterface {

  /**
   * Is app.
   *
   * @var bool
   */
  private $isApp;

  /**
   * Merchant redirect URL.
   *
   * @var string
   */
  private $merchantRedirectUrl;

  /**
   * Merchant agreement URL.
   *
   * @var string
   */
  private $merchantAgreementUrl;

  /**
   * Customer phone number.
   *
   * @var string
   */
  private $customerPhoneNumber;

  /**
   * Product subscription.
   *
   * @var \Drupal\vipps_recurring_payments\Entity\ProductSubscriptionInterface
   */
  private $product;

  /**
   * Is initial charge.
   *
   * @var bool
   */
  private $initialCharge;

  /**
   * DraftAgreementData constructor.
   *
   * @param \Drupal\vipps_recurring_payments\Entity\ProductSubscriptionInterface $product
   *   Product.
   * @param string $merchantRedirectUrl
   *   Merchant redirect url.
   * @param string $merchantAgreementUrl
   *   Merchant agreement url.
   * @param string $customerPhoneNumber
   *   Customer phone number.
   * @param bool $isApp
   *   Is app.
   */
  public function __construct(
    ProductSubscriptionInterface $product,
    string $merchantRedirectUrl,
    string $merchantAgreementUrl,
    string $customerPhoneNumber,
    bool $isApp
  ) {
    $this->product = $product;
    $this->merchantRedirectUrl = $merchantRedirectUrl;
    $this->merchantAgreementUrl = $merchantAgreementUrl;
    $this->customerPhoneNumber = $customerPhoneNumber;
    $this->isApp = $isApp;
    $this->initialCharge = $this->product->getInitialCharge();
  }

  /**
   * Get product.
   *
   * @return \Drupal\vipps_recurring_payments\Entity\ProductSubscriptionInterface
   *   Product subscription.
   */
  public function getProduct():ProductSubscriptionInterface {
    return $this->product;
  }

  /**
   * Get draft agreement data as array.
   *
   * @return array
   *   Data.
   */
  public function getData(): array {
    $data = [
      "currency" => $this->product->getCurrency(),
      "interval" => $this->product->getIntervalValue(),
      "intervalCount" => $this->product->getIntervalCount(),
      "isApp" => $this->isApp,
      "merchantRedirectUrl" => $this->merchantRedirectUrl,
      "merchantAgreementUrl" => $this->merchantAgreementUrl,
      "customerPhoneNumber" => $this->customerPhoneNumber,
      "price" => $this->product->getIntegerPrice(),
      "productDescription" => $this->product->getDescription(),
      "productName" => $this->product->getTitle(),
    ];

    if ($this->initialCharge) {
      $data = array_merge($data, [
        "initialCharge" => [
          "amount" => $this->product->getIntegerPrice(),
          "currency" => $this->product->getCurrency(),
          "description" => $this->product->getDescription(),
          "transactionType" => "DIRECT_CAPTURE",
        ],
      ]);
      if ($this->product->getOrderId()) {
        $data["initialCharge"]['orderId'] = $this->product->getOrderId();
      }
    }

    return $data;
  }

}

==> vipps_recurring_payments-8.x-2.3-beta2.tar.gz: vipps_recurring_payments/src/RequestStorage/DraftAgreementData.php <==
<?php

declare(strict_types=1);

namespace Drupal\vipps_recurring_payments\RequestStorage;

use Drupal\vipps_recurring_payments\Entity\ProductSubscriptionInterface;

/**
 * Class Draft Agreement Data.
 *
 * @package Drupal\vipps_recurring_payments\RequestStorage
 */
class DraftAgreementData implements RequestStorageInterface {

  /**
   * Is app.
   *
   * @var bool
   */
  private $isApp;

  /**
   * Merchant redirect URL.
   *
   * @var string
   */
  private $merchantRedirectUrl;

  /**
   * Merchant agreement URL.
   *
   * @var string
   */
  private $merchantAgreementUrl;

  /**
   * Customer phone number.
   *
   * @var string
   */
  private $customerPhoneNumber;

  /**
   * Idempotency-Key, unique API field.
   *
   * @var string
   */
  private $IdempotencyKey;

  /**
   * Product subscription.
   *
   * @var \Drupal\vipps_recurring_payments\Entity\ProductSubscriptionInterface
   */
  private $product;

  /**
   * Is initial charge.
   *
   * @var bool
   */
  private $initialCharge;

  /**
   * DraftAgreementData constructor.
   *
   * @param \Drupal\vipps_recurring_payments\Entity\ProductSubscriptionInterface $product
   *   Product.
   * @param string $merchantRedirectUrl
   *   Merchant redirect url.
   * @param string $merchantAgreementUrl
   *   Merchant agreement url.
   * @param string $customerPhoneNumber
   *   Customer phone number.
   * @param bool $isApp
   *   Is app.
   * @param string $IdempotencyKey
   *   Idempotency key.
   */
  public function __construct(
    ProductSubscriptionInterface $product,
    string $merchantRedirectUrl,
    string $merchantAgreementUrl,
    string $customerPhoneNumber,
    bool $isApp,
    string $IdempotencyKey
  ) {
    $this->product = $product;
    $this->merchantRedirectUrl = $merchantRedirectUrl;
    $this->merchantAgreementUrl = $merchantAgreementUrl;
    $this->customerPhoneNumber = $customerPhoneNumber;
    $this->isApp = $isApp;
    $this->initialCharge = $this->product->getInitialCharge();
    $this->IdempotencyKey = $IdempotencyKey;
  }

  /**
   * Get product.
   *
   * @return \Drupal\vipps_recurring_payments\Entity\ProductSubscriptionInterface
   *   Product subscription.
   */
  public function getProduct():ProductSubscriptionInterface {
    return $this->product;
  }

  /**
   * Get draft agreement data as array.
   *
   * @return array
   *   Data.
   */
  public function getData(): array {
    $data = [
      "interval" => [
        "unit"  =>$this->product->getIntervalValue(),
        "count" => $this->product->getIntervalCount(),
      ],
      "isApp" => $this->isApp,
      "merchantRedirectUrl" => $this->merchantRedirectUrl,
      "merchantAgreementUrl" => $this->merchantAgreementUrl,
      "customerPhoneNumber" => $this->customerPhoneNumber,
      "pricing" => $this->product->getPricing(),
      "productDescription" => $this->product->getDescription(),
      "productName" => $this->product->getTitle(),
    ];

    if ($this->initialCharge) {
      $data = array_merge($data, [
        "initialCharge" => [
          "amount" => $this->product->getIntegerPrice(),
          "currency" => $this->product->getCurrency(),
          "description" => $this->product->getDescription(),
          "transactionType" => "DIRECT_CAPTURE",
        ],
      ]);
      if ($this->product->getOrderId()) {
        $data["initialCharge"]['orderId'] = $this->product->getOrderId();
      }
    }

    return $data;
  }

  /**
   * @inheritdoc.
   */
  public function getIdempotencyKey(): string
  {
    return $this->IdempotencyKey;
  }

}
